@@ -1,3 +1,19 @@
+// Copyright (C) 2015 - 2016  Dmitriy Selivanov
+// This file is part of text2vec
+//
+// text2vec is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
+// (at your option) any later version.
+//
+// text2vec is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with text2vec.  If not, see <http://www.gnu.org/licenses/>.
+
 #include "SparseTripletMatrix.h"
 using namespace Rcpp;
 using namespace std;
@@ -44,7 +60,7 @@ protected:
   // stopwords
   RCPP_UNORDERED_SET<string> stopwords;
   // documents
-  SparseTripletMatrix<uint32_t> dtm;
+  SparseTripletMatrix<int> dtm;
 
   //#####Glove related
   uint64_t cooc_tokens_number;
